@@ -6,6 +6,7 @@ void SetConsoleMsgStream(MESSAGE_TYPE MsgStream);
 void SetConsoleRedirectCharset(RAR_CHARSET RedirectCharset);
 void ProhibitConsoleInput();
 void OutComment(const std::wstring &Comment);
+bool IsConsoleOutputPresent();
 
 #ifndef SILENT
 bool GetConsolePassword(UIPASSWORD_TYPE Type,const std::wstring &FileName,SecPassword *Password);
@@ -16,13 +17,13 @@ bool GetConsolePassword(UIPASSWORD_TYPE Type,const std::wstring &FileName,SecPas
   inline void eprintf(const wchar *fmt,...) {}
   inline void Alarm() {}
   inline int Ask(const wchar *AskStr) {return 0;}
-  inline bool getwstr(std::wstring &str) {return false;}
+  inline void getwstr(std::wstring &str) {}
 #else
   void mprintf(const wchar *fmt,...);
   void eprintf(const wchar *fmt,...);
   void Alarm();
   int Ask(const wchar *AskStr);
-  bool getwstr(std::wstring &str);
+  void getwstr(std::wstring &str);
 #endif
 
 #endif
