@@ -6,24 +6,16 @@ RAROptions::RAROptions()
 }
 
 
-RAROptions::~RAROptions()
-{
-  // It is important for security reasons, so we do not have the unnecessary
-  // password data left in memory.
-  memset(this,0,sizeof(RAROptions));
-}
-
-
 void RAROptions::Init()
 {
   memset(this,0,sizeof(RAROptions));
   WinSize=0x2000000;
+  WinSizeLimit=0x100000000;
   Overwrite=OVERWRITE_DEFAULT;
   Method=3;
   MsgStream=MSG_STDOUT;
   ConvertNames=NAMES_ORIGINALCASE;
-  ProcessEA=true;
-  xmtime=EXTTIME_HIGH3;
+  xmtime=EXTTIME_MAX;
   FileSizeLess=INT64NDF;
   FileSizeMore=INT64NDF;
   HashType=HASH_CRC32;
