@@ -32,6 +32,9 @@
 #ifdef _WIN_ALL
 #include "isnt.hpp"
 #endif
+#ifdef PROPAGATE_MOTW
+#include "motw.hpp"
+#endif
 #include "file.hpp"
 #include "crc.hpp"
 #include "filefn.hpp"
@@ -61,6 +64,8 @@
 
 #include "threadpool.hpp"
 
+#include "largepage.hpp"
+
 #include "unpack.hpp"
 
 
