@@ -27,7 +27,7 @@ RSCoder16::~RSCoder16()
   delete[] MX;
   delete[] ValidFlags;
 }
-    
+
 
 // Initialize logarithms and exponents Galois field tables.
 void RSCoder16::gfInit()
@@ -41,7 +41,7 @@ void RSCoder16::gfInit()
     gfExp[L]=E;
     gfExp[L+gfSize]=E;  // Duplicate the table to avoid gfExp overflow check.
     E<<=1;
-    if (E>gfSize) 
+    if (E>gfSize)
       E^=0x1100B; // Irreducible field-generator polynomial.
   }
 
@@ -59,7 +59,7 @@ uint RSCoder16::gfAdd(uint a,uint b) // Addition in Galois field.
 }
 
 
-uint RSCoder16::gfMul(uint a,uint b) // Multiplication in Galois field. 
+uint RSCoder16::gfMul(uint a,uint b) // Multiplication in Galois field.
 {
   return gfExp[gfLog[a]+gfLog[b]];
 }
@@ -95,7 +95,9 @@ bool RSCoder16::Init(uint DataCount, uint RecCount, bool *ValidityFlags)
     if (NE > ValidECC || NE == 0 || ValidECC == 0)
       return false;
   }
-  if (ND + NR > gfSize || NR > ND || ND == 0 || NR == 0)
+
+  // 2021.09.01 - we allowed RR and REV >100%, so no more NR > ND check.
+  if (ND + NR > gfSize || /*NR > ND ||*/ ND == 0 || NR == 0)
     return false;
 
   delete[] MX;
@@ -144,7 +146,7 @@ void RSCoder16::MakeDecoderMatrix()
 }
 
 
-// Apply GaussJordan elimination to find inverse of decoder matrix.
+// Apply Gauss-Jordan elimination to find inverse of decoder matrix.
 // We have the square NDxND matrix, but we do not store its trivial
 // diagonal "1" rows matching valid data, so we work with NExND matrix.
 // Our original Cauchy matrix does not contain 0, so we skip search
@@ -156,7 +158,7 @@ void RSCoder16::InvertDecoderMatrix()
   for (uint Kr = 0, Kf = 0; Kr < NE; Kr++, Kf++)
   {
     while (ValidFlags[Kf]) // Skip trivial rows.
-      Kf++;                 
+      Kf++;
     MI[Kr * ND + Kf] = 1;  // Set diagonal 1.
   }
 
@@ -174,7 +176,7 @@ void RSCoder16::InvertDecoderMatrix()
       // after MI[..]^=, but we do not need it for matrix inversion.
       for (uint I = 0; I < NE; I++)
         MI[I * ND + Kf] ^= MX[I * ND + Kf];
-      Kf++;                 
+      Kf++;
     }
 
     if (Kf == ND)
@@ -186,14 +188,14 @@ void RSCoder16::InvertDecoderMatrix()
     uint PInv = gfInv( MXk[Kf] ); // Pivot inverse.
     // Divide the pivot row by pivot, so pivot cell contains 1.
     for (uint I = 0; I < ND; I++)
-    { 
+    {
       MXk[I] = gfMul( MXk[I], PInv );
       MIk[I] = gfMul( MIk[I], PInv );
     }
 
     for (uint I = 0; I < NE; I++)
       if (I != Kr) // For all rows except containing the pivot cell.
-      { 
+      {
         // Apply Gaussian elimination Mij -= Mkj * Mik / pivot.
         // Since pivot is already 1, it is reduced to Mij -= Mkj * Mik.
         uint *MXi = MX + I * ND; // i-th row of main matrix.
@@ -331,14 +333,14 @@ bool RSCoder16::SSE_UpdateECC(uint DataNum, uint ECCNum, const byte *Data, byte
 
   for (uint I=0;I<16;I++)
   {
-    ((byte *)&T0L)[I]=gfMul(I,M);
-    ((byte *)&T0H)[I]=gfMul(I,M)>>8;
-    ((byte *)&T1L)[I]=gfMul(I<<4,M);
-    ((byte *)&T1H)[I]=gfMul(I<<4,M)>>8;
-    ((byte *)&T2L)[I]=gfMul(I<<8,M);
-    ((byte *)&T2H)[I]=gfMul(I<<8,M)>>8;
-    ((byte *)&T3L)[I]=gfMul(I<<12,M);
-    ((byte *)&T3H)[I]=gfMul(I<<12,M)>>8;
+    ((byte *)&T0L)[I]=byte(gfMul(I,M));
+    ((byte *)&T0H)[I]=byte(gfMul(I,M)>>8);
+    ((byte *)&T1L)[I]=byte(gfMul(I<<4,M));
+    ((byte *)&T1H)[I]=byte(gfMul(I<<4,M)>>8);
+    ((byte *)&T2L)[I]=byte(gfMul(I<<8,M));
+    ((byte *)&T2H)[I]=byte(gfMul(I<<8,M)>>8);
+    ((byte *)&T3L)[I]=byte(gfMul(I<<12,M));
+    ((byte *)&T3H)[I]=byte(gfMul(I<<12,M)>>8);
   }
 
   size_t Pos=0;
@@ -361,7 +363,7 @@ bool RSCoder16::SSE_UpdateECC(uint DataNum, uint ECCNum, const byte *Data, byte
     __m128i LowBytes1=_mm_and_si128(D[1],LowByteMask);
     __m128i HighBytes=_mm_packus_epi16(HighBytes0,HighBytes1);
     __m128i LowBytes=_mm_packus_epi16(LowBytes0,LowBytes1);
-    
+
     // Multiply bits 0..3 of low bytes. Store low and high product bytes
     // separately in cumulative sum variables.
     __m128i LowBytesLow4=_mm_and_si128(LowBytes,Low4Mask);
@@ -377,7 +379,7 @@ bool RSCoder16::SSE_UpdateECC(uint DataNum, uint ECCNum, const byte *Data, byte
     // Add new product to existing sum, low and high bytes separately.
     LowBytesMultSum=_mm_xor_si128(LowBytesMultSum,LowBytesHigh4MultLow);
     HighBytesMultSum=_mm_xor_si128(HighBytesMultSum,LowBytesHigh4MultHigh);
-    
+
     // Multiply bits 0..3 of high bytes. Store low and high product bytes separately.
     __m128i HighBytesLow4=_mm_and_si128(HighBytes,Low4Mask);
     __m128i HighBytesLow4MultLow=_mm_shuffle_epi8(T2L,HighBytesLow4);
@@ -413,7 +415,7 @@ bool RSCoder16::SSE_UpdateECC(uint DataNum, uint ECCNum, const byte *Data, byte
   // because Data and ECC can have different alignment offsets.
   for (; Pos<BlockSize; Pos+=2)
     *(ushort*)(ECC+Pos) ^= gfMul( M, *(ushort*)(Data+Pos) );
-  
+
   return true;
 }
 #endif
